@@ -55,7 +55,7 @@ sub drop {
   # NG 10-09-15: added DROP VIEW 
   # my $sql="drop table if exists $name";
   # wantarray? ($sql): [$sql];
-  my @sql=(qq(DROP TABLE IF EXISTS $name),qq(DROP View IF EXISTS $name));
+  my @sql=(qq(DROP TABLE IF EXISTS $name),qq(DROP VIEW IF EXISTS $name));
   wantarray? @sql: \@sql;
 }
 # NG 09-12-27: quick hack to let abbreviated types match in CollectionDiff
